#!/usr/bin/perl
#
#  Kill-nav-commenters-gif.pl
#  By John Gruber  <http://daringfireball.net/>
#  Free software licensed under the same terms as Perl itself.
#
#  v1.0 - Mon 28 Feb 2005
#
#  Kill-nav-commenters-gif is a plug-in for Movable Type 3.1x which
#  patches two of MT's internal subroutines so that MT no longer creates
#  a file named 'nav-commenters.gif' at the root level of each of your
#  weblogs. A copy of 'nav-commenters.gif' already exists in the static
#  /images/ folder that ships as part of any MT installation; this
#  plug-in patches MT to use that copy of 'nav-commenters.gif' instead of
#  creating a new one for each weblog.
#
#  (Technically, this plug-in doesn't suppress MT's creation/re-creation
#  of 'nav-commenters.gif', but rather, each time MT creates it, this
#  plug-in deletes it. Less to patch this way.)
#
#  Installation and use: Place a copy of this plug-in in the "plugins"
#  folder inside your Movable Type installation. If this folder doesn't
#  exist, create it first. Then, rebuild your weblog(s). That's it,
#  you're done. (To uninstall, remove it from your "plugins" folder and
#  rebuild.)
#

local $^W = 0;

#
# First, patch `MT::rebuild` so that we delete the 'nav-commenters.gif' files
# it insists upon creating each time you rebuild.
#
require MT;
my $original_rebuild = \&MT::rebuild;
my $my_rebuild = sub {
	my $mt = shift;
	my %param = @_;

	# Call MT's internal rebuild() routine.
	$original_rebuild->($mt, %param);

	# Now, delete 'nav-commenters.gif' if it exists.
	my $blog;
	unless ($blog = $param{Blog}) {
		my $blog_id = $param{BlogID};
		$blog = MT::Blog->load($blog_id) or
			return $mt->error(
				$mt->translate("Load of blog '[_1]' failed: [_2]",
					$blog_id, MT::Blog->errstr));
	}
	my $identity_link_image = $blog->site_path . "/nav-commenters.gif";
	if (-f $identity_link_image) {
		if (unlink $identity_link_image) {
			$mt->log("Deleted nav-commenters.gif");
		}
	}
};
*MT::rebuild = $my_rebuild;

#
# Second, redefine the CommentAuthorIdentity tag, which is the only tag
# that calls the routine that makes the assumption that
# 'nav-commenters.gif' is located at the root level of your web site.
# What we do is create our own handler, which first calls the original
# (built-in) handler for CommentAuthorIdentity,
# `MT::Template::Context::_hdlr_comment_author_identity`, and we stash
# away the output of that handler. Then we try to build a URL pointing
# to the copy of 'nav-commenters.gif' in the static /images/ folder
# that ships with Movable Type, and we substitute this path for the
# path output by `MT::Template::Context::_hdlr_comment_author_identity`.
#
require MT::Template::Context;
my $my_author_id = sub {
	my $out = MT::Template::Context::_hdlr_comment_author_identity(@_);
	if (defined $out) {
		# Here's where we patch, to use the nav-commenters.gif from your
		# StaticWebPath, rather than the one that MT tries to create in your
		# root-level weblog directory by default.
		my $static_path = MT::Template::Context->_hdlr_static_path();
		$static_path =~ s{/$}{}; # if $static_path is just '/', we want to make it empty
		unless ($static_path) {
			$static_path = MT::Template::Context->_hdlr_cgi_path();
			$static_path =~ s{/$}{};
		 }
		 unless ($static_path =~ m{^https?://}i) {
			my $server = MT::Template::Context->_hdlr_cgi_path();
			$server =~ s{/$}{};
			$server =~ s{^(https?://[^/]+)/.*}{$1}i;
			$static_path = $server . $static_path;
		}
		$out =~ s{src='.*/nav-commenters.gif}{src='$static_path/images/nav-commenters.gif};
	}
	$out;
};
MT::Template::Context->add_tag('CommentAuthorIdentity' => $my_author_id);

1;
